#[non_exhaustive]pub enum AnyTypeInfoKind {
Postgres(PgTypeInfo),
MySql(MySqlTypeInfo),
Sqlite(SqliteTypeInfo),
Mssql(MssqlTypeInfo),
Odbc(OdbcTypeInfo),
}Available on crate feature
any and (crate features mssql or mysql or odbc or postgres or sqlite) only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Postgres(PgTypeInfo)
Available on crate feature
postgres only.MySql(MySqlTypeInfo)
Available on crate feature
mysql only.Sqlite(SqliteTypeInfo)
Available on crate feature
sqlite only.Mssql(MssqlTypeInfo)
Available on crate feature
mssql only.Odbc(OdbcTypeInfo)
Available on crate feature
odbc only.Trait Implementations
Sourceimpl Clone for AnyTypeInfoKind
impl Clone for AnyTypeInfoKind
Sourcefn clone(&self) -> AnyTypeInfoKind
fn clone(&self) -> AnyTypeInfoKind
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnyTypeInfoKind
impl Debug for AnyTypeInfoKind
Sourceimpl PartialEq for AnyTypeInfoKind
impl PartialEq for AnyTypeInfoKind
Sourcefn eq(&self, other: &AnyTypeInfoKind) -> bool
fn eq(&self, other: &AnyTypeInfoKind) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AnyTypeInfoKind