pub struct AnyConnection(/* private fields */);Available on (crate features
mysql or sqlite or postgres or mssql or odbc) and crate feature any only.Expand description
A connection to any SQLx database.
The database driver used is determined by the scheme of the connection url.
postgres://postgres@localhost/test
sqlite://a.sqliteImplementations