pub struct MismatchedTypeError {
pub rust_type: String,
pub rust_sql_type: String,
pub sql_type: String,
pub source: Option<Box<dyn Error + Send + Sync>>,
}Expand description
Error indicating that a Rust type is not compatible with a SQL type.
Fields
rust_type: StringThe name of the Rust type.
rust_sql_type: StringThe SQL type name that the Rust type would map to.
sql_type: StringThe actual SQL type from the database.
source: Option<Box<dyn Error + Send + Sync>>Optional source error that caused the mismatch.
Implementations
Sourceimpl MismatchedTypeError
impl MismatchedTypeError
Sourcepub fn new<DB, T>(ty: &<DB as Database>::TypeInfo) -> MismatchedTypeError
pub fn new<DB, T>(ty: &<DB as Database>::TypeInfo) -> MismatchedTypeError
Create a new mismatched type error without a source.