Oid

Struct Oid 

pub struct Oid(pub u32);
Available on crate feature postgres only.
The PostgreSQL OID type stores an object identifier, used internally by PostgreSQL as primary keys for various system tables.

Tuple Fields

0: u32

The raw unsigned integer value sent over the wire