pub struct LockedSqliteHandle<'a> { /* private fields */ }Available on crate feature
sqlite only.Implementations
Sourceimpl LockedSqliteHandle<'_>
impl LockedSqliteHandle<'_>
Sourcepub fn as_raw_handle(&mut self) -> NonNull<sqlite3>
pub fn as_raw_handle(&mut self) -> NonNull<sqlite3>
Returns the underlying sqlite3* connection handle.
As long as this LockedSqliteHandle exists, it is guaranteed that the background thread
is not making FFI calls on this database handle or any of its statements.