ColumnIndex

Trait ColumnIndex 

pub trait ColumnIndex<T>: Sealed + Debug
where T: ?Sized,
{ // Required method fn index(&self, container: &T) -> Result<usize, Error>; }
A type that can be used to index into a Row or Statement.

The get and try_get methods of Row accept any type that implements ColumnIndex. This trait is implemented for strings which are used to look up a column by name, and for usize which is used as a positional index into the row.

This trait is sealed and cannot be implemented for types outside of SQLx.

Required Methods

fn index(&self, container: &T) -> Result<usize, Error>

Returns a valid positional index into the row or statement, ColumnIndexOutOfBounds, or, ColumnNotFound.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ColumnIndex<AnyRow> for usize

Source

fn index(&self, row: &AnyRow) -> Result<usize, Error>

Source

impl ColumnIndex<AnyStatement<'_>> for usize

Source

fn index(&self, statement: &AnyStatement<'_>) -> Result<usize, Error>

Source

impl ColumnIndex<MssqlRow> for &str

Source

impl ColumnIndex<MssqlRow> for usize

Source

impl ColumnIndex<MssqlStatement<'_>> for &str

Source

fn index(&self, statement: &MssqlStatement<'_>) -> Result<usize, Error>

Source

impl ColumnIndex<MssqlStatement<'_>> for usize

Source

fn index(&self, statement: &MssqlStatement<'_>) -> Result<usize, Error>

Source

impl ColumnIndex<MySqlRow> for &str

Source

impl ColumnIndex<MySqlRow> for usize

Source

impl ColumnIndex<MySqlStatement<'_>> for &str

Source

fn index(&self, statement: &MySqlStatement<'_>) -> Result<usize, Error>

Source

impl ColumnIndex<MySqlStatement<'_>> for usize

Source

fn index(&self, statement: &MySqlStatement<'_>) -> Result<usize, Error>

Source

impl ColumnIndex<OdbcRow> for &str

Source

impl ColumnIndex<OdbcRow> for usize

Source

impl ColumnIndex<OdbcStatement<'_>> for &str

Source

fn index(&self, statement: &OdbcStatement<'_>) -> Result<usize, Error>

Source

impl ColumnIndex<OdbcStatement<'_>> for usize

Source

fn index(&self, statement: &OdbcStatement<'_>) -> Result<usize, Error>

Source

impl ColumnIndex<PgRow> for &str

Source

fn index(&self, row: &PgRow) -> Result<usize, Error>

Source

impl ColumnIndex<PgRow> for usize

Source

fn index(&self, row: &PgRow) -> Result<usize, Error>

Source

impl ColumnIndex<PgStatement<'_>> for &str

Source

fn index(&self, statement: &PgStatement<'_>) -> Result<usize, Error>

Source

impl ColumnIndex<PgStatement<'_>> for usize

Source

fn index(&self, statement: &PgStatement<'_>) -> Result<usize, Error>

Source

impl ColumnIndex<SqliteRow> for &str

Source

impl ColumnIndex<SqliteRow> for usize

Source

impl ColumnIndex<SqliteStatement<'_>> for &str

Source

fn index(&self, statement: &SqliteStatement<'_>) -> Result<usize, Error>

Source

impl ColumnIndex<SqliteStatement<'_>> for usize

Source

fn index(&self, statement: &SqliteStatement<'_>) -> Result<usize, Error>

Source

impl<'i> ColumnIndex<AnyRow> for &'i str
where &'i str: AnyColumnIndex,

Source

fn index(&self, row: &AnyRow) -> Result<usize, Error>

Source

impl<'i> ColumnIndex<AnyStatement<'_>> for &'i str
where &'i str: AnyColumnIndex,

Source

fn index(&self, statement: &AnyStatement<'_>) -> Result<usize, Error>

Source

impl<T, I> ColumnIndex<T> for &I
where I: ColumnIndex<T> + ?Sized, T: ?Sized,

Source

fn index(&self, row: &T) -> Result<usize, Error>

Implementors