pub trait Execute<'q, DB>: Sized + Sendwhere
DB: Database,{
// Required methods
fn sql(&self) -> &'q str;
fn statement(&self) -> Option<&<DB as HasStatement<'q>>::Statement>;
fn take_arguments(&mut self) -> Option<<DB as HasArguments<'q>>::Arguments>;
fn persistent(&self) -> bool;
}Expand description
Required Methods
Sourcefn statement(&self) -> Option<&<DB as HasStatement<'q>>::Statement>
fn statement(&self) -> Option<&<DB as HasStatement<'q>>::Statement>
Gets the previously cached statement, if available.
Sourcefn take_arguments(&mut self) -> Option<<DB as HasArguments<'q>>::Arguments>
fn take_arguments(&mut self) -> Option<<DB as HasArguments<'q>>::Arguments>
Returns the arguments to be bound against the query string.
Returning None for Arguments indicates to use a โsimpleโ query protocol and to not
prepare the query. Returning Some(Default::default()) is an empty arguments object that
will be prepared (and cached) before execution.
Sourcefn persistent(&self) -> bool
fn persistent(&self) -> bool
Returns true if the statement should be cached.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".